<?php $app_version = "v13.0.0.24"; $app_revdate = "22 Feb 2023";
/*************************************************************************
Folio Multipage document handler for TNG
Written by William Bisbee, http://www.bisbeefamily.com.
Displays a folder of page files as a multi-page document.

version 13.0.0.18 Revised to work with TNGv13
version 13.0.0.19 Revised to use tabs mapping to page numbers.
version 13.0.0.20 Revised to permit a string to be used as a tab map
version 13.0.0.21 Revised to expand tab map with range desig ( i[23-64] )
version 13.0.0.22 Combines v12 and v13 -- compatible with both
version 13.0.0.23 Fixes bug causing MM "not unique" errors.
version 13.0.0.24 Now uses TNG database interface. // not released yet //
*************************************************************************
showfolio.php
start < < < < < < < < < < < < < < < < < < < < < < < < < < < < <
DN                                                            UP
|---->IF no args ----> Warnings --- done                       |
|                                                              |
|--->IF [mediaID]:                                             |
|      * Retrieve Folio Data From Media Tables                 |
|      * Get contents of folio control file                    |
|      * Construct PDF link if requested                       |
|      * Construct array of links to associated entities       |
|      * Get array of sorted page files                        |
|      * Resolve tab map if any                                |
|      * Store data in SESSION                                 |
|          mediaID, mediatypeID, description, notes            |
|          owner, linkstr, tabmap[], fileNames[]               |
|                                                              |
|--->IF [index]:                                               |
|--->IF [tabnr]:                                               |
|      * Get Data from SESSION                                 |
|      * Normalize requested folio page index                  |
|      * Get page file name, size and extension type           |
|      * Create horizontal page tabs                           |
|      * ADD                                                   |
|         - Previous page button                               |
|         - First anchor tab and ellipsis                      |
|         - Inner tabs                                         |
|         - Last anchor tab                                    |
|         - Next page button                                   |
|         - Tab selection box                                  |
|      * Create log entry and bookmark                         |
|      * Create document hearder                               |
|      * Create Album style header                             |
|      * Display content of page file                          |
|      * Display meta data at bottom of page                   |
|                                                              |
|      Tab --------------------------------------------------->| [index]
|      Tab box ----------------------------------------------->| [tabnr]
|                                                              |
|      link to associated entity (person, source, etc) ----------->(new tab/page)
|                                                              |
DN                                                            UP
> > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > >
*/
$textpart = "showphoto";
$debug = false;
include 'tng_begin.php';

/************************************************************************
USE MYSQLI IF AVAILABLE
************************************************************************/
if( !empty( $debug ) )
{
	error_reporting( E_ALL );
	ini_set( 'display_errors', 'on' );
	ini_set( 'error_log', 'error.log' );
}
else
{
	error_reporting( E_ERROR );
	ini_set( 'display_errors', 0 );
}
/*************************************************************************
LANGUAGE SUPPORT
*************************************************************************/
// include user-provided language support if any
if( file_exists( $mylanguage.'/folio_text.php' ) )
	include $mylanguage.'/folio_text.php';
else
	// otherwise default to this (English)
	include 'languages/English-UTF8/folio_text.php';

/*************************************************************************
GLOBAL PREFERENCES SET BY SHOWFOLIO MOD EDITOR
**************************************************************************/
$restricted = 0;
$centerpages = 0;
$showddmenus = 1;
$showmagnifier = 1;
$showinfo = 1;
$bordersize = 0;
$bordercolor = "gray";
$text_align = !empty( $centerpages ) ? 'center' : 'left';
$table_align = !empty( $centerpages ) ?"style='margin-left:auto;margin-right:auto;'" :'';

/*************************************************************************
WORKING LINKS
**************************************************************************/
$showfolio_url		 = getURL( 'showfolio', 1 );
$pdffetch_url			= getURL( "pdffetch", 1 );
$getperson_url		 = getURL( 'getperson', 1 );
$familygroup_url		= getURL( 'familygroup', 1 );
$placesearch_url		= getURL( 'placesearch', 1 );
$showsource_url		= getURL( 'showsource', 1 );
$showrepo_url			= getURL( 'showrepo', 1 );
$bookmarks_url		 = getURL( 'bookmarks', 1 );
$addbookmark_url		= getURL( "ajx_addbookmark", 1 );
$admin_editmedia_url = getURL( 'admin_editmedia', 1 );
$browsemedia_url		= getURL( 'browsemedia', 1 );
$home_url				= getURL( 'index', 0 );
$login_url				= getURL( 'login', 0 );
$home_icon				= $cms['tngpath'].'img/tng_home.gif';
$media_icon			 = $cms['tngpath'].'img/tng_media.gif';
$print_icon			 = $cms['tngpath'].'img/tng_print.gif';
$bookmark_icon		 = $cms['tngpath'].'img/tng_bmk.gif';
/*************************************************************************
RETRIEVE FOLIO DATA FROM MEDIA TABLES
**************************************************************************/
// showfolio is called with query string: showfolio.php?mediaID=327
if( empty( $mediaID ) )
{ # no args
	header( "Location:{$homepage}");
	exit;
}

// get mediaID for folio from media_table
$query = "SELECT * from $media_table WHERE mediaID=$mediaID";
$result = tng_query( $query );
$row = tng_fetch_assoc( $result );

if( empty( $row ) )
{ # bad ID number
	header( "Location:{$homepage}");
	exit;
}

if( !empty( $mediaID ) )
{
  /* This function defined in mediatypes.php creates arrays --
  ** $mediatypes_xxxx[$ID] -- containing information about all defined media types */
  initMediatypes();

  /* extract needed information from the media_table query.
  /* ID can be almost any collection containing a folio. */
  $ID = $row['mediatypeID'];
  $description = $row['description'];
  $notes = insertLinks( $row['notes'] );
  $owner = $row['owner'];
  $subpath = $row['path'];

  foreach( $mediatypes as $mediatype )
  {
  	if( $mediatype['mediatypeID'] == $ID )
  	{
  		$path = $mediatype['path'];
  		break;
  	}
  }

  /* The following are for Wordpress compatibility. */
  $mediapath_rel = $path.'/'.$subpath;
  $mediapath_abs = $rootpath.$mediapath_rel;
  $dirname_rel = pathinfo( $mediapath_rel, PATHINFO_DIRNAME );
  $dirname_abs = pathinfo( $mediapath_abs, PATHINFO_DIRNAME );

  /* Define path for use with folio-relative images in html page files. */
  define( "__FOLIO__", $dirname_rel.'/' );

  if (isset($text[$ID]))
  	$display = $text[$ID];
  else
  	$display = $mediatypes_display[$ID];

  $header_icon = empty( $mediatypes_icons[$ID] ) ?
  	// use sprite
  	"<span class=\"headericon\" id=\"$ID-hdr-icon\"></span>" :
  	// use icon
  	"<img src=\"".$cms['tngpath'].$mediatypes_icons[$ID]."\" width=\"20\" height=\"20\" alt=\"\" style=\"vertical-align:-2px\"	border=\"0\"/>";
  /*************************************************************************
  GET CONTENTS OF FOLIO CONTROL FILE
  **************************************************************************/
  // Cannot "include" folio.php because it contains a redirection
  $buffer = file_get_contents( $mediapath_abs ); // path to folio

  if( false !== $buffer )
  {
  	// Remove php tags from buffer
  	$search = array('<?php','?>');
  	$buffer = str_replace( $search, '', $buffer );

  	// Remove redirection from top of folio.php
  	$buffer = str_replace( "header", "//", $buffer );

  	eval( $buffer );
  }

  // force login if access is restricted
  if ($restricted && !$currentuser) header("Location: {$login_url}");

  // initialize array if not set in control file
  if( !isset( $exclude ) ) $exclude = array();
  /*************************************************************************
  CONSTRUCT PDF LINK IF REQUESTED
  *************************************************************************/
  $pdfhref = '';
  if( !empty( $pdffetch) )
  {
  	// use pdffetch to download file from protected location
  	$pdfhref = $pdffetch_url.'pdf='.$pdffetch;
  }
  elseif( !empty( $pdflink ) )
  {
  	// use direct link to download pdf file
  	$pdfhref = $dirname_rel.'/'.$pdflink;
  }
  /*************************************************************************
  CONSTRUCT FOLIO MEDIA LINKS TO ASSOCIATED ENTITIES
  	will show in info area at bottom of folio pages
  **************************************************************************/
  $medialinks = array();
  $query = "SELECT * FROM $medialinks_table WHERE mediaID = '$mediaID' ORDER BY linktype";

  $result = tng_query( $query );
  while( $row = tng_fetch_assoc( $result ) )
  {
    $medialinks[] = $row;
  }

  $linkStr = "";
  foreach($medialinks as $medialink)
  {
  	$personID = $medialink['personID'];
  	$tree = $medialink['gedcom'];
  	switch ($medialink['linktype'])
  	{
  		case 'I':
  			$linkname = getPersonName($personID, $tree);
  			//$linkStr .= "<a href=\"{$cms['tngpath']}getperson.php?personID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			$linkStr .= "<a href =\"{$getperson_url}personID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			break;
  		case 'F':
  			$linkname = getCoupleName($personID, $tree);
  			//$linkStr .= "<a href=\"{$cms['tngpath']}familygroup.php?familyID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			$linkStr .= "<a href =\"{$familygroup_url}familyID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			break;
  		case 'L':
  			$linkname = $personID;
  			//$linkStr .= "<a href=\"{$cms['tngpath']}placesearch.php?psearch=$personID&amp;tree=$tree\">$linkname</a>; ";
  			$linkStr .= "<a href =\"{$placesearch_url}psearch=$personID&amp;tree=$tree\">$linkname</a>; ";
  			break;
  		case 'S':
  			$linkname= getSourceName($personID, $tree);
  			//$linkStr .= "<a href=\"{$cms['tngpath']}showsource.php?sourceID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			$linkStr .= "<a href =\"{$showsource_url}sourceID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			break;
  		case 'R':
  			$linkname= getRepoName($personID, $tree);
  			//$linkStr .= "<a href=\"{$cms['tngpath']}showrepo.php?repoID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			$linkStr .= "<a href =\"{$showrepo_url}repoID=$personID&amp;tree=$tree\">$linkname</a>; ";
  			break;
  		default:
  			die (__LINE__.": unrecognized media link type");
  			break;
  	}
  }
  $linkStr = substr($linkStr, 0, -2);
  /*************************************************************************
  GET ARRAY OF SORTED PAGE FILES
  **************************************************************************/
  $allowed = array(
  	".jpg", ".JPG",
  	".jpeg", ".JPEG",
  	".gif", ".GIF",
  	".png", ".PNG",
  	".htm", ".HTM",
  	".html", ".HTML",
  	".php", ".PHP"
  );

  $imgList = array(
  	".jpg", ".JPG",
  	".jpeg", ".JPEG",
  	".gif", ".GIF",
  	".png", ".PNG"
  );

  $fileNames = array();
  $istabs = false;
  if( $handle = opendir( $dirname_abs ) )
  {
  	while( false !== ( $file = readdir($handle ) ) )
  	{
  		strtolower( $file );
  		// these files will always be exluded as page files
  		if( $file == "folio.php" ) continue;
  		if( $file == "index.php" ) continue; // backward compatibility
  		if( $file == "init.php" ) continue; // backward compatibility
  		$ext = strrchr( $file, '.' );
  		if( in_array( $ext, $allowed ) )
  			if( !in_array( $ext, $exclude ) )
  				$fileNames[] = $dirname_rel.'/'.$file;
  	}
  	closedir($handle);
  }
  //print_r( $fileNames );exit;
  $pageCount=count($fileNames);
  if ($pageCount > 1)
  {
  	sort($fileNames);
  }

  /****************************
  	TAB MAP
  ****************************/
  if( !empty( $tabmap ) )
  {
   	if( !is_array( $tabmap ) )
  	{
  		// The $tabmap is given as a string - convert to array
  		$temp = explode( ",", $tabmap );
  		$tabmap = array();
  		foreach( $temp as $value )
  		{
  			$tabmap[] = trim($value);
  		}
  	}

  	// Expand tab map fill range with sequential numbers
  	for( $i=0; isset($tabmap[$i]); $i++ )
  	{
  		// Expand range in this format '[42-324]' with incrementing numbers
  		if( preg_match( "#([a-zA-Z]?)\[([0-9]+)-([0-9]+)\]#", $tabmap[$i], $matches ) )
  		{
  			// Create array from the range
  			$j = $matches[2];
  			while( $j <= $pageCount && $j <= $matches[3] )
  			{
  				$range_arr[] = $matches[1].$j++;
  			}

  			// Replace the range notation with expanded range array
  			array_splice( $tabmap, $i, 1, $range_arr );
  			$range_arr = array();
  		}
  	}
  }
  else
    $tabmap = array();

  unset( $_SESSION['folio'] );
  $_SESSION['folio']['mediaID'] = $mediaID;
  $_SESSION['folio']['mediatypeID'] = $ID;
  $_SESSION['folio']['description'] = $description;
  $_SESSION['folio']['notes'] = $notes;
  $_SESSION['folio']['owner'] = $owner;
  $_SESSIOn['folio']['linkstr'] = $linkstr;
  $_SESSION['folio']['tabmap'] = $tabmap;
  $_SESSION['folio']['fileNames'] = $fileNames;
  $_SESSION['folio']['usecover'] = !empty( $usecover ) ? $usecover : 0;
  $_SESSION['folio']['buttonlabel'] = !empty( $buttonlabel ) ? $buttonlabel : '';
  $_SESSION['folio']['pdfhref'] = !empty( $pdfhref ) ? $pdfhref : '';
} // if mediaID

if( !empty( $index ) || !empty( $tabnr ) )
{
  foreach( $_SESSION['folio'] as $key => $value )
  {
    ${$key} = $value;
  }
}
/*************************************************************************
NORMALIZE REQUESTED FOLIO PAGE INDEX
**************************************************************************/
/**
 **	A request from the tab number box.
 **	The $tabnr is a tab label that can be "looked up" in the tab map
 **	or used as is if no tab map.
 **/
if( !empty( $tabnr ) )
{
	if( !empty( $tabmap ) )
	{
		// Set the tab index using the $tabnr (label) key from the map array
		//$index = array_search( $tabnr, $tabmap );
		$index = array_search(strtolower($tabnr), array_map('strtolower', $tabmap ) );

		// Set the page label from the map array
		$page = $tabmap[$index];

	}
	else
	{
		// Normal tab number
		if( !is_numeric( $tabnr ) )
		{
			$index == 0;
		}
		else
		{
			$index = !empty( $usecover ) ? $tabnr : $tabnr - 1;
		}
	}
}
// A page request from a bookmark user log entry
elseif( !empty( $page ) )
{
	// set index == $tabmap key
	$index = array_search( $page, $tabmap );
}

// Normalize index
$index = isset( $index ) ? $index : 0;
$index = $index < 0 ? 0 : $index;
$index = $index > $pageCount - 1 ? $pageCount - 1 : $index;
/*************************************************************************
GET PAGE FILE NAME, SIZE AND EXTENSION TYPE
**************************************************************************/
//$pageFile_abs = $fileNames[$index]; // absolute path by RM
$pageFile_abs = $rootpath.$fileNames[$index]; // absolute path by RM
//$pageFile_rel = str_replace( $rootpath, '', $pageFile_abs );
$pageFile_rel = $fileNames[$index]; // relative path by RM
//echo __LINE__,' ',$pageFile_abs,' & ',$pageFile_rel;exit;
$filesize = formatbytes($pageFile_abs, "KB");
$ext = strrchr($pageFile_abs, '.');
/*************************************************************************
CREATE HORIZONTAL PAGE TABS
*************************************************************************/
$tabstr = '';

// if only one page do not show tab line
if( $pageCount	> 1 )
{
	/*********************************************************************
	DETERMINE Inner TAB RANGE AND ELLIPSES
		First and last page tabs will always be displayed
		Inner tabs between them may require ellipsis before and/or after
	*********************************************************************/

	// number of inner tabs to show on either side of requested page (default=2)
	$sidetabs = isset($sidetabs) ? $sidetabs : 2;

	// set maximum allowable Inner tabs
	$maxInnerTabs = $sidetabs * 2 + 1;

	// set actual number of inner tabs to lesser of $maxInnerTabs or $pageCount - 2
	$innerTabs =	$maxInnerTabs > $pageCount - 2 ? $pageCount - 2 : $maxInnerTabs;

	// set Inner index range
	$firstInnerIdx = $index - $sidetabs;
	$lastInnerIdx = $firstInnerIdx + $innerTabs - 1;

	// when requested index is tight right, move the Inner tabs left
	while( $lastInnerIdx > $pageCount - 2 )
	{
		$lastInnerIdx--;
		$firstInnerIdx--;
	}

	// when requested index is tight left, move the Inner tabs right
	while( $firstInnerIdx < 1 )
	{
		$firstInnerIdx++;
		$lastInnerIdx++;
	}

	// set the ellipses for missing sequence of tab numbers
	$frontEllipsis = $firstInnerIdx > 1 ? ". . ." : null;
	$backEllipsis = $lastInnerIdx < $pageCount - 2 ? ". . ." : null;

/*************************************************************************
ADD PREVIOUS PAGE BUTTON
*************************************************************************/
	$prev = $index - 1;
	if ( $index > 0 )
	{ // show live link
		$prevButton = "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=$prev\" class=\"snlink\"
		title=\"{$text['fo_prevpage']}\">
		<font size='4'>&laquo;</font>&nbsp;{$text['fo_page']}</a>";
	}
	else
	{ // show dead link
		$prevButton = "<span class=\"snlink snlinkact\"
		title=\"{$text['fo_prevpage']}\">
			<font size='4'>&laquo;</font>&nbsp;{$text['fo_page']}</span>\n";
	}
	$tabstr .= "$prevButton\n";
	/*************************************************************************
	ADD FIRST ANCHOR TAB AND ELLIPSIS
		first and last file tabs are always displayed
	*************************************************************************/
	// anchor tab will either be labeled per map, as a cover or as page 1
	if( isset( $tabmap[0] ) )
	{
		$tablabel = $tabmap[0];
	}
	elseif( !empty( $usecover ) )
	{
		if( !empty( $buttonlabel ) )
		{
			if( !empty( $text[$buttonlabel] ) )
			{
				$tablabel = $text[$buttonlabel];
			}
			else {
				$tablabel = $buttonlabel;
			}
		}
		else {
			$tablabel = $text['fo_cover'];
		}
		$covertab = $tablabel;
		$page = null;	// not needed for title (tooltip)
		$fotab = null;	// style not needed to set cover tab width
	}
	else
	{
		$tablabel = 1;
		$page = "page";	// used in title (tooltip)
		$fotab = "fotab"; // style sets tab width
	}
	// when first anchor tab is requested create simulated (inactive) link
	if( $index == 0 )
	{
	 $tabstr .= "<span class=\"snlink snlinkact $fotab\"
		title=\"$page $tablabel\">$tablabel</span>\n";
	}
	else
	{ // create live link - index always zero for first page file
				$tabstr .= "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=0\" class=\"snlink $fotab\"
			title=\"$page $tablabel\">$tablabel</a>\n";
	}
/*************************************************************************
ADD THE Inner TABS
	Inner tabs lie between the first and last anchor tabs
	if the span is too large to show all tabs, use ellipses for missing tabs
*************************************************************************/
	$tabstr .= $frontEllipsis;
	for( $i = $firstInnerIdx; $i <= $lastInnerIdx; $i++ )
	{
		// A tab map is being used
		if( isset( $tabmap[$i] ) )
		{
			// Get the tab label from the tab map
			$tablabel = $tabmap[$i];
		}
		else
		{
			// If no tabmap and cover page is used, tab labels = index numbers
			// if no cover, tabs = index + 1
			$tablabel = !empty( $usecover ) ? $i : $i + 1;
		}

		// when current page is requested create simulated (inactive) link
		if( $i == $index )
		{
			// create dead link
			$tabstr .= "<span class=\"snlink snlinkact fotab\"
			title=\"page $tablabel\">$tablabel</span>\n";
		}
		else
		{
			// create live link
			$tabstr .= "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=$i\" class=\"snlink fotab\"
			title=\"page $tablabel\">$tablabel</a>\n";
		}
	}
	$tabstr .= $backEllipsis;
/*************************************************************************
ADD THE LAST ANCHOR TAB
*************************************************************************/
	$lastAnchorIdx = $pageCount - 1;	// index for last anchor tab

	if( isset( $tabmap[$lastAnchorIdx] ) )
	{
		// Get right-hand anchor tab label from the tab map
		$tablabel = $tabmap[$lastAnchorIdx];
	}
	else
	{
		// Use a tab number for right-hand anchor tab
		$tablabel = !empty( $usecover ) ? $pageCount - 1 : $pageCount;
	}

	if( $index == $pageCount - 1 )
	{
		// create dead link
	 $tabstr .= "<span class=\"snlink snlinkact fotab\"
		title=\"page $tablabel\">$tablabel</span>\n";
	}
	else
	{
		// create live link
		$tabstr .= "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=$lastAnchorIdx\" class=\"snlink fotab\"
		title=\"page $tablabel\">$tablabel</a>\n";
	}
/*************************************************************************
ADD NEXT PAGE BUTTON
*************************************************************************/
	$next = $index + 1;
	if ( $index < $pageCount - 1 )
	{
		$nextButton="<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=$next\" class=\"snlink\"
		title=\"{$text['fo_nextpage']}\">{$text['fo_page']}&nbsp;<font size='4'>&raquo;</font></a>";
	}
	else
	{
		// show dead link
		$nextButton = "<span class=\"snlink snlinkact\" title=\"{$text['fo_nextpage']}\">{$text['fo_page']}&nbsp;<font size='4'>&raquo;</font></span>\n";
	}
	$tabstr .= $nextButton;
/*************************************************************************
CREATE A TAB SELECTION BOX
*************************************************************************/
	$formstr = getFORM( "showfolio", "GET", null, null, null );
	$tabselector = "
$formstr &nbsp;{$text['fo_enterpage']}&nbsp;
<input type=\"text\" size=\"4\" name=\"tabnr\" />
<input type=\"hidden\" name=\"mediaID\" value=\"$mediaID\" />
<input type=\"submit\" value=\"&lt;--\" class=\"none\" />
</form>";
} // pageCount > 1: tab string has been constructed
/*************************************************************************
CONSTRUCT A COMPLETE TAB LINE FROM ITS ELEMENTS
*************************************************************************/
// use cells in a one-row table to vertically align all the tab line elements
if( !empty( $tabstr ) || !empty( $pdfhref ) )
{
	$outstr	= "
<table $table_align>
<tr>";
	if( !empty( $tabstr ) )
	{
		$outstr .= "
	<td>
		$tabstr
	</td>
	<td nowrap=\"nowrap\" style='vertical-align:bottom;'>
		$tabselector
	</td>";
	}

	// add PDF button if there is a download
	if( !empty( $pdfhref ) )
	{
		$outstr .= "
	<td width='5'>&nbsp;</td>
	<td nowrap=\"nowrap\" style='vertical-align:bottom;padding-bottom:2px;'>
		<a style=\"float:right\" href=\"$pdfhref\" class=\"snlink\" title=\"{$text['fo_downloadpdf']}\">PDF</a>
	</td>
	<td width='5'>&nbsp;</td>";
	}
	$outstr .= "
</tr>
</table>
<br style='clear:both' />
";
}
/**********************************************************
MAKE TNG LOG ENTRY - SET BOOKMARK
***********************************************************/
$title = $description;
if( $pageCount > 1)
{
	$title .= ", ";

	if( $istabs )
	{
		// Use tab label from the tab map ($tabmap)
		$page = $tabmap[$index];
		$title .= "page " . $page;
	}

	// Use normal tab index number + 1
	elseif( empty( $usecover ) )
	{
		$title .= "tab " . ($index+1);
	}

	// Use tab index number (offset by cover tab)
	elseif( $index > 0 )
	{
		$title .= "tab " . $index;
	}

	// Use the defined cover tab
	else
	{
		$title .= $covertab;
	}
}

if( $istabs ){
	// log and bookmark the document page number
	$logstring = "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;page=$page\">$title</a>";
}
else
{
	// Log and bookmark the Folio tab index number
	$logstring = "<a href=\"{$showfolio_url}mediaID=$mediaID&amp;index=$index\">$title</a>";
}
# If you dont want image views logged, comment out the next line
writelog($logstring);
preparebookmark($logstring);
/**********************************************************
CREATE HTML DOCUMENT HEADER
***********************************************************/

$flags['scripting'] = "
<style type = \"text/css\" >
.fotab {
	display:inline-block;
	min-width:2em;
	text-align:center;
}
</style>
";
$flags['noheader'] = false;
$flags['nobody'] = false;
$flags['noicons'] = $showddmenus ? false : true;
tng_header( $title, $flags );
/*************************************************************************
DISPLAY AN ALBUM STYLE HEADER
*************************************************************************/
$header = $description;
if ($allow_edit && empty( $tngprint ) )
{
	$header .= "&nbsp;<a href=\"{$admin_editmedia_url}mediaID=$mediaID&amp;cw=1\" target=\"_blank]\" title=\"{$text['editmedia']}\"><img src=\"{$cms['tngpath']}img/tng_aedit.gif\" border=\"0\"></a>";
}
if( !$showddmenus && empty( $tngprint ) )
{
	echo "
<div style=\"display:table;width:65%;text-align:center;\">
<div style=\"display:table-row\">

<div style=\"display:table-cell;width:25%;\">
<div style=\"vertical-align:bottom;\">
	&nbsp;<img src=\"$home_icon\" width=\"16\" style=\"vertical-align:bottom;\"/>
	&nbsp;<a href=\"$home_url\">{$text['homepage']}</a>
</div>
</div>

<div style=\"display:table-cell;width:25%;text-align:center;\">
<div style=\"vertical-align:bottom;\">
	&nbsp;<img src=\"$media_icon\" width=\"16\"style=\"vertical-align:bottom;\"/>
	&nbsp;<a href=\"{$browsemedia_url}mediatypeID=$ID\">".ucfirst( $ID )."</a>
</div>
</div>

<div style=\"display:table-cell;width:25%;text-align:center;\">
<div style=\"vertical-align:bottom;\">
	&nbsp;<img src=\"$print_icon\" width=\"16\" style=\"vertical-align:bottom;\"/>";

if( !$tngconfig['showprint'] && $sitever != "mobile")
	{
		if( $text['tngprint'] == 'Print' ) $text['tngprint'] = 'Printer friendly';
		echo "
&nbsp;<a href=\"{$showfolio_url}mediaID=$mediaID&amp;tngprint=1\">{$text['tngprint']}</a>";
	}

echo "
</div>
</div>

<div style=\"display:table-cell;width:25%;text-align:center;\">
<div style=\"vertical-align:bottom;\">
	&nbsp;<img src=\"$bookmark_icon\" width=\"16\" style=\"vertical-align:bottom;\"/>
	&nbsp;<a href=\"$bookmarks_url\" onclick=\"tnglitbox = new LITBox('{$addbookmark_url}p=" . urlencode($cms['tngpath']) . "',{width:350,height:100}); return false;\">{$text['bookmark']}</a>
</div>
</div>

</div>
</div>
<br />";
}

echo "
<table $table_align cellpadding=\"0\" cellspacing=\"0\">
<tr>
<td valign=\"top\">
<a href=\"{$browsemedia_url}mediatypeID=$ID\" title=\"{$text['showall']} $display\">$header_icon</a>
</td>
<td>
<h1 class=\"header\" style=\"margin-bottom:0px; margin-left:5px;\">$header</h1>
<span class=\"normal\" style=\"margin-left:5px;\">$notes</span>
</td>
</tr>
</table>
<br style='clear:both;' /><br />";
if( isset( $outstr ) && empty( $tngprint ) ) echo $outstr;
/**********************************************************
DISPLAY CONTENT OF PAGE FILE
***********************************************************/
// Display image as page file
if (in_array($ext, $imgList))
{
	list ($width, $height) = getimagesize($pageFile_abs);
	$imgSize = "$width x $height";
	echo "
<div style='text-align:$text_align;min-height:1280;min-width:680;'>
<img src=\"$pageFile_rel\" style=\"max-width:100%;margin-top:5px; border:{$bordersize}px solid $bordercolor;\" onmouseover=\"TJPzoomif(this);\" id=\"pageImg\" alt=\"Document\" />
</div>";
}
// Display html or php page file
else {
	$imgSize = "n/a";
	if ( !empty( $pageFile_abs ) )
	{
//echo __LINE__,' ',$pageFile;exit;
		if( $ext == '.htm' || $ext == '.html' || $ext == '.php' )
		{
			show_webpage( $pageFile_rel );
		}
	}
}
/**********************************************************
DISPLAY META DATA AT BOTTOM OF PAGE
***********************************************************/
echo "<hr />
<table border=\"0\" cellspacing=\"1\" cellpadding=\"4\" width=\"100%\" class=\"whiteback\">
<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['photoowner']}
</td>
<td class=\"databack\">
$owner
</td>
</tr>
";
if( !empty( $showinfo ) )
{
	echo "<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['filename']}
</td>
<td class=\"databack\">
$pageFile_rel
</td>
</tr>

<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['filesize']}
</td>
<td class=\"databack\">
$filesize
</td>
</tr>

<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['fo_mediaid']}
</td>
<td class=\"databack\">
$mediaID
</td>
</tr>

<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['photosize']}
</td>
<td class=\"databack\">
$imgSize
</td>
</tr>

<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
Folio version
</td>
<td class=\"databack\">
$app_version ($app_revdate)
</td>
</tr>
";
}
echo "<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['indlinked']}
</td>
<td class=\"databack\">
$linkStr
</td>
</tr>";
if( !empty( $pdfhref ) && empty( $tngprint ) )
{
	echo "
<tr>
<td style=\"width:100px\" class=\"fieldnameback fieldname\">
{$text['fo_downloadpdf']}
</td>
<td class=\"databack\">
<a href=\"$pdfhref\" >$description</a>, $notes
</td>
</tr>";
}
echo "
</table>";

if( empty( $tngprint ) )
{
echo "
<table>
<tr>
<td style=\"width:280px;\">
<a href=\"javascript:scroll(0,0)\" target=\"_self\" class=\"snlink\" >{$text['fo_backtotop']}</a>
";
if ( $index > 0)
	echo	"&nbsp;
$prevButton
";
if ( $index < $pageCount - 1 )
	echo "&nbsp;
$nextButton
";

echo "</td>
</tr>
</table>";
}

if( !empty( $showmagnifier ) )
{
echo "
<script type=\"text/javascript\" src=\"js/ddpowerzoomer.js\"></script>
<script>
jQuery(document).ready(function($){ //fire on DOM ready
 $('#pageImg').addpowerzoom({
	defaultpower: 2,
	powerrange: [2,2],
	largeimage: null,
	magnifiersize:[400,100]
 })
})
$ = jQuery; // added to prevent lightbox.js code failing
</script>
";
}
tng_footer( "" );
/*************************************************************************
FUNCTIONS
*************************************************************************/
function getRepoName ($sourceID, $tree)
{
global $repositories_table;
	$query = "SELECT * FROM $repositories_table WHERE repoID = '$sourceID' AND gedcom='$tree' ";

  $result = tng_query( $query );
  $row = tng_fetch_assoc( $result );
	if( !empty( $row ) )
		return $rows['reponame'];
	else
		return '';
}

function getSourceName ($sourceID, $tree)
{
global $sources_table;
	$query = "SELECT * FROM $sources_table WHERE sourceID = '$sourceID' AND gedcom='$tree' ";

  $result = tng_query( $query );
  $row = tng_fetch_assoc( $result );
	if( !empty( $row ) )
		return $row['title'];
	else
		return '';
}

function getCoupleName($familyID, $tree)
{
global $families_table;
	$query = "SELECT * FROM $families_table WHERE familyID = '$familyID' AND gedcom='$tree' ";
	$rows = db_select( $query );

  $result = tng_query( $query );
  $row = tng_fetch_assoc( $result );

	if( !empty( $row ) ) {
		$husband = $row['husband'];
		$wife = $row['wife'];
		$name = getPersonName($husband, $tree) . "/" . getPersonName($wife, $tree);
		return $name;
	}
	return '';
}

function getPersonName($personID, $tree)
{
global $people_table;
	$name = "";
	$query = "SELECT gedcom, firstname, lastname FROM $people_table WHERE personID = '$personID' AND gedcom ='$tree' ";

  $result = tng_query( $query );
  $row = tng_fetch_assoc( $result );
	if( !empty( $row ) ) {
		$name = $row['firstname'] . " " . $row['lastname'];
		return $name;
	}
	return '';
}

function formatbytes($file, $type)
{
	switch($type)
	{
		case "KB":
			$filesize = filesize($file) * .0009765625; // bytes to KB
			break;
		case "MB":
			$filesize = (filesize($file) * .0009765625) * .0009765625; // bytes to MB
			break;
		case "GB":
			$filesize = ((filesize($file) * .0009765625) * .0009765625) * .0009765625; // bytes to GB
			break;
	}
	if($filesize <= 0)
		return $filesize = 'unknown';
	else
		return round($filesize, 2).' '.$type;
}

/* Resolve image paths in page files -- check folder-relative first
** if no file exists, accept path as tng-relative (no action required) */function show_webpage( $pagefile_abs )
{
	$contents = file_get_contents( $pagefile_abs );
	preg_match_all( "#src\s*=\s*[\"\'\\\]*([^\"\'\\\]*)#", $contents, $matches, PREG_SET_ORDER );
	for( $i=0; isset($matches[$i][1]); $i++ )
	{
		$path = __FOLIO__.$matches[$i][1];

		// if folder-relative file, replace with full root-relative path
		if( file_exists( $path ) )
		{
			$contents = str_replace( $matches[$i][1], $path, $contents );
		}
		// otherwise assume path is already root-relative and do nothing
	}
	// display the page file
	eval( '?>'.$contents );
}
